# TelescopeML

![logo](logo_TelescopeML.png)

** `TelescopeML`: Deep Convolutional Neural Networks and Machine Learning Models for Analyzing Stellar and Exoplanetary Telescope Spectra**

## Brief introduction

``TelescopeML`` is a Python package comprising a series of modules, each equipped with specialized machine learning and
statistical capabilities for conducting Convolutional Neural Networks (CNN) or Machine Learning (ML) training on
datasets captured from the atmospheres of extrasolar planets and brown dwarfs. 

## Main Features and Modules:

- *StatVisAnalyzer*: Explore and process the synthetic datasets (or the training examples) and perform statistical analysis.
- *DeepBuilder*: Specify training and target features, normalize/scale datasets, and construct a CNN model.
- *DeepTrainer*: Create an ML model, train the model with the training examples, and utilize hyperparameters.
- *Predictor*: Train the module using specified hyperparameters.


## Documentation

- Documentation: https://ehsangharibnezhad.github.io/TelescopeML/
- Installation: https://ehsangharibnezhad.github.io/TelescopeML/installation.html
- Tutorials: https://ehsangharibnezhad.github.io/TelescopeML/tutorials.html
- The code: https://ehsangharibnezhad.github.io/TelescopeML/code.html
- Concepts: https://ehsangharibnezhad.github.io/TelescopeML/knowledgebase.html

